@@ -1,22 +1,39 @@
 """
 Land Cover
 
-This model calculates historic land use change over a twenty-year period, extending the
-functionality of the Blonk model.
+This model calculates historic land use change over a twenty-year period,
+extending the functionality of the Blonk model.
 """
 import math
 from collections import defaultdict
+from datetime import datetime, timedelta
+
 from hestia_earth.schema import SiteSiteType, TermTermType
 from hestia_earth.utils.lookup import (
-    download_lookup, get_table_value, column_name,
-    extract_grouped_data_closest_date, _is_missing_value, extract_grouped_data
+    download_lookup, get_table_value, column_name, _is_missing_value, extract_grouped_data
 )
 from hestia_earth.utils.model import filter_list_term_type
-from hestia_earth.utils.tools import safe_parse_float, to_precision, non_empty_value
+from hestia_earth.utils.tools import safe_parse_float, to_precision
 
 from hestia_earth.models.log import logRequirements, log_as_table, logShouldRun
+from hestia_earth.models.utils.constant import DAYS_IN_YEAR
 from hestia_earth.models.utils.management import _new_management
 from hestia_earth.models.utils.term import get_lookup_value
+from hestia_earth.models.utils.blank_node import _node_date, DatestrFormat, _gapfill_datestr, DatestrGapfillMode
+from .utils import (
+    IPCC_LAND_USE_CATEGORY_ANNUAL,
+    IPCC_LAND_USE_CATEGORY_PERENNIAL,
+    LAND_USE_TERMS_FOR_TRANSFORMATION,
+    ANNUAL_CROPLAND,
+    PERMANENT_CROPLAND,
+    FOREST_LAND,
+    OTHER_LAND,
+    PERMANENT_PASTURE,
+    TOTAL_CROPLAND,
+    TOTAL_AGRICULTURAL_CHANGE,
+    ALL_LAND_USE_TERMS,
+    crop_ipcc_land_use_category,
+)
 from . import MODEL
 
 REQUIREMENTS = {
@@ -33,7 +50,10 @@ REQUIREMENTS = {
                 "@type": "Management",
                 "value": "",
                 "term.termType": "landCover",
-                "endDate": ""
+                "or": {
+                    "startDate": "",
+                    "endDate": ""
+                }
             }
         ]
     }
@@ -64,35 +84,12 @@ LOOKUPS = {
         "Permanent meadows and pastures"
     ],
     "crop": ["cropGroupingFaostatArea", "IPCC_LAND_USE_CATEGORY"],
-    "landCover": ["cropGroupingFaostatProduction", "FAOSTAT_LAND_AREA_CATEGORY"]
+    "landCover": ["cropGroupingFaostatProduction", "FAOSTAT_LAND_AREA_CATEGORY"],
+    "property": "CALCULATE_TOTAL_LAND_COVER_SHARE_SEPARATELY"
 }
 MODEL_KEY = 'landCover'
 
 LAND_AREA = LOOKUPS["region-faostatArea"][3]
-TOTAL_CROPLAND = "Cropland"
-ANNUAL_CROPLAND = "Arable land"
-FOREST_LAND = "Forest land"
-OTHER_LAND = "Other land"
-PERMANENT_CROPLAND = "Permanent crops"
-PERMANENT_PASTURE = "Permanent meadows and pastures"
-TOTAL_AGRICULTURAL_CHANGE = "Total agricultural change"
-ALL_LAND_USE_TERMS = [
-    FOREST_LAND,
-    TOTAL_CROPLAND,
-    ANNUAL_CROPLAND,
-    PERMANENT_CROPLAND,
-    PERMANENT_PASTURE,
-    OTHER_LAND
-]
-# Mapping from Land use terms to Management node terms.
-# land use term: (@id, name)
-LAND_USE_TERMS_FOR_TRANSFORMATION = {
-    FOREST_LAND: ("forest", "Forest"),
-    ANNUAL_CROPLAND: ("annualCropland", "Annual cropland"),
-    PERMANENT_CROPLAND: ("permanentCropland", "Permanent cropland"),
-    PERMANENT_PASTURE: ("permanentPasture", "Permanent pasture"),
-    OTHER_LAND: ("otherLand", OTHER_LAND)  # Not used yet
-}
 SITE_TYPES = {
     SiteSiteType.CROPLAND.value,
     SiteSiteType.FOREST.value,
@@ -100,8 +97,7 @@ SITE_TYPES = {
     SiteSiteType.PERMANENT_PASTURE.value
 }
 DEFAULT_WINDOW_IN_YEARS = 20
-IPCC_LAND_USE_CATEGORY_ANNUAL = "Annual crops"
-IPCC_LAND_USE_CATEGORY_PERENNIAL = "Perennial crops"
+DATE_TOLERANCE_IN_YEARS = 2
 OUTPUT_SIGNIFICANT_DIGITS = 3
 
 
@@ -127,33 +123,14 @@ def site_area_sum_to_100(dict_of_percentages: dict):
          math.isclose(sum(dict_of_percentages.values()), 0.0, rel_tol=0.01))
 
 
-def _lookup_land_use_type(nodes: list) -> str:
-    """Look up the land use type from a management node."""
-    return "" if nodes == [] else get_lookup_value(
-        lookup_term=nodes[0].get("term", {}),
-        column=LOOKUPS.get("landCover")[1],
-        model=MODEL,
-        term=nodes[0].get("term", {})
+def _should_group_landCover(term: dict):
+    return any(
+        bool(get_lookup_value(lookup_term=prop.get("term", {}), column="CALCULATE_TOTAL_LAND_COVER_SHARE_SEPARATELY"))
+        for prop in term.get("properties", [])
     )
 
 
-def _crop_ipcc_land_use_category(
-    crop_term_id: str,
-    lookup_term_type: str = TermTermType.LANDCOVER.value
-) -> str:
-    """
-    Looks up the crop in the lookup.
-    Returns the IPCC_LAND_USE_CATEGORY.
-    """
-    return get_lookup_value(
-        lookup_term={"@id": crop_term_id, "type": "Term", "termType": lookup_term_type},
-        column=LOOKUPS.get("crop")[1],
-        model=MODEL,
-        term={"@id": crop_term_id, "type": "Term", "termType": lookup_term_type}
-    )
-
-
-def get_changes(country_id: str, end_year: int) -> dict:
+def get_changes(country_id: str, end_year: int) -> tuple[dict, bool]:
     """
     For each entry in ALL_LAND_USE_TERMS, creates a key: value in output dictionary, also TOTAL
     """
@@ -162,14 +139,18 @@ def get_changes(country_id: str, end_year: int) -> dict:
         land_use_term: safe_parse_float(
             extract_grouped_data(
                 get_table_value(lookup, 'termid', country_id, column_name(land_use_term)),
-                str(end_year))
+                str(end_year)),
+            default=None
         )
         for land_use_term in ALL_LAND_USE_TERMS + [LAND_AREA]
     }
-    changes_dict[TOTAL_AGRICULTURAL_CHANGE] = (float(changes_dict.get(TOTAL_CROPLAND, 0))
-                                               + float(changes_dict.get(PERMANENT_PASTURE, 0)))
+    missing_changes = any(val is None for val in changes_dict.values())
+    changes_dict = {k: v if v is not None else 0 for k, v in changes_dict.items()}
+    changes_dict[TOTAL_AGRICULTURAL_CHANGE] = (
+        float(changes_dict.get(TOTAL_CROPLAND, 0)) + float(changes_dict.get(PERMANENT_PASTURE, 0))
+    )
 
-    return changes_dict
+    return changes_dict, missing_changes
 
 
 def _get_ratio_start_and_end_values(
@@ -181,7 +162,7 @@ def _get_ratio_start_and_end_values(
     # expansion over twenty years / current area
     lookup = download_lookup('region-faostatArea.csv')
     table_value = get_table_value(lookup, 'termid', country_id, column_name(fao_name))
-    end_value = safe_parse_float(value=extract_grouped_data_closest_date(table_value, end_year), default=None)
+    end_value = safe_parse_float(value=extract_grouped_data(table_value, str(end_year)), default=None)
     return max(0.0, _safe_divide(numerator=expansion, denominator=end_value))
 
 
@@ -399,7 +380,7 @@ def _get_complete_faostat_to_crop_mapping() -> dict:
             get_table_value(lookup, 'termid', crop_term_id, column_name("cropGroupingFaostatArea"))
         )
         if key:
-            mappings[key].append(_crop_ipcc_land_use_category(crop_term_id=crop_term_id, lookup_term_type="crop"))
+            mappings[key].append(crop_ipcc_land_use_category(crop_term_id=crop_term_id, lookup_term_type="crop"))
     return {
         fao_name: max(set(crop_terms), key=crop_terms.count)
         for fao_name, crop_terms in mappings.items()
@@ -412,15 +393,29 @@ def _get_harvested_area(country_id: str, year: int, faostat_name: str) -> float:
     """
     lookup = download_lookup("region-crop-cropGroupingFaostatProduction-areaHarvested.csv")
     return safe_parse_float(
-        value=extract_grouped_data_closest_date(
+        value=extract_grouped_data(
             data=get_table_value(lookup, "termid", country_id, column_name(faostat_name)),
-            year=year
+            key=str(year)
         ),
         default=None
     )
 
 
-def _run_make_management_nodes(existing_nodes: list, percentage_transformed_from: dict, start_year: int) -> list:
+def _get_term_id_for_crop(nodes: set, land_type: str) -> str:
+    """Use the original crop term id for permanent/perennial crops and the land use id for other types."""
+    result = next(
+        (node for node in nodes if crop_ipcc_land_use_category(node[0]) == IPCC_LAND_USE_CATEGORY_PERENNIAL), None
+    )
+    return (
+        # Take first perennial crop - not multi-cropping
+        result[0] if land_type == PERMANENT_CROPLAND and result else
+        LAND_USE_TERMS_FOR_TRANSFORMATION[land_type][0]
+    )
+
+
+def _run(site: dict, existing_nodes: list, percentage_transformed_from: dict):
+    start_year = _get_year_from_landCover(existing_nodes[0]) - DEFAULT_WINDOW_IN_YEARS
+
     """Creates a list of new management nodes, excluding any dates matching existing ones."""
     existing_nodes_set = {
         (node.get("term", {}).get("@id", ""), node.get("startDate"), node.get("endDate"))
@@ -435,15 +430,19 @@ def _run_make_management_nodes(existing_nodes: list, percentage_transformed_from
             "percentage": 0 if ratio == -0.0 else to_precision(
                 number=ratio * 100,
                 digits=OUTPUT_SIGNIFICANT_DIGITS
-            )
+            ),
+            "term_id": _get_term_id_for_crop(existing_nodes_set, land_type=land_type)
         }
         for land_type, ratio in percentage_transformed_from.items()
     ]
     values = [v for v in values if v.get("land_management_key") not in existing_nodes_set]
 
+    for value in values:
+        logShouldRun(site, MODEL, value.get("term_id"), True, model_key=MODEL_KEY)
+
     return [
         _management(
-            term_id=LAND_USE_TERMS_FOR_TRANSFORMATION[value.get("land_type")][0],
+            term_id=value.get("term_id"),
             value=value.get("percentage"),
             start_date=value.get("land_management_key")[1],
             end_date=value.get("land_management_key")[2]
@@ -527,14 +526,18 @@ def _get_net_expansion_cultivated_vs_harvested(annual_crops_net_expansion, chang
     return net_expansion_cultivated_vs_harvested
 
 
-def _should_run_historical_land_use_change(site: dict, land_use_type: str) -> tuple[bool, dict]:
-    management_nodes = filter_list_term_type(site.get("management", []), TermTermType.LANDCOVER)
+def _get_year_from_landCover(node: dict):
+    date = node.get('startDate') or node.get('endDate')
+    return int(date[:4])
+
+
+def _should_run_historical_land_use_change(site: dict, nodes: list, land_use_type: str) -> tuple[bool, dict]:
     # Assume a single management node for single-cropping.
     return _should_run_historical_land_use_change_single_crop(
         site=site,
-        term=management_nodes[0].get("term", {}),
+        term=nodes[0].get("term", {}),
         country_id=site.get("country", {}).get("@id"),
-        end_year=int(management_nodes[0].get("endDate")[:4]),
+        end_year=_get_year_from_landCover(nodes[0]),
         land_use_type=land_use_type
     )
 
@@ -548,7 +551,7 @@ def _should_run_historical_land_use_change_single_crop(
 ) -> tuple[bool, dict]:
     """Calculate land use change percentages for a single management node/crop."""
     # (C-H).
-    changes = get_changes(country_id=country_id, end_year=end_year)
+    changes, missing_changes = get_changes(country_id=country_id, end_year=end_year)
 
     # (L). Estimate maximum forest loss
     forest_loss = _estimate_maximum_forest_change(
@@ -678,6 +681,8 @@ def _should_run_historical_land_use_change_single_crop(
     site_area[land_use_type] = 1 - sum(site_area.values())
 
     sum_of_site_areas_is_100 = site_area_sum_to_100(site_area)
+    site_type_allowed = site.get("siteType") in SITE_TYPES
+
     logRequirements(
         log_node=site,
         model=MODEL,
@@ -685,43 +690,89 @@ def _should_run_historical_land_use_change_single_crop(
         model_key=MODEL_KEY,
         land_use_type=land_use_type,
         country_id=country_id,
+        changes=log_as_table(changes),
         site_area=log_as_table(site_area),
-        sum_of_site_areas_is_100=sum_of_site_areas_is_100
+        sum_of_site_areas_is_100=sum_of_site_areas_is_100,
+        site_type_allowed=site_type_allowed
     )
 
-    should_run = all(
-        [
-            site.get("siteType"),
-            country_id,
-            non_empty_value(term),
-            site.get("siteType") in SITE_TYPES,
-            sum_of_site_areas_is_100
-        ]
-    )
-    logShouldRun(site, MODEL, term=term.get("@id"), should_run=should_run, key=MODEL_KEY)
+    should_run = all([not missing_changes, country_id, site_type_allowed, sum_of_site_areas_is_100])
+    logShouldRun(site, MODEL, term.get("@id"), should_run, model_key=MODEL_KEY)
 
     return should_run, site_area
 
 
-def _should_run(site: dict) -> tuple[bool, dict]:
-    management_nodes = filter_list_term_type(site.get("management", []), TermTermType.LANDCOVER)
-    land_use_type = _lookup_land_use_type(nodes=management_nodes)
-    should_run_result, site_area = (
-        (False, {}) if land_use_type not in {ANNUAL_CROPLAND, PERMANENT_CROPLAND, PERMANENT_PASTURE}
-        else _should_run_historical_land_use_change(
-            site=site,
-            land_use_type=land_use_type
-        )
+def _get_land_use_term_from_node(node: dict) -> str:
+    return get_lookup_value(
+        lookup_term=node.get("term", {}),
+        column=LOOKUPS.get("landCover")[1],
+        model=MODEL,
+        term=node.get("term", {})
     )
 
-    return should_run_result, site_area
+
+def _collect_land_use_types(nodes: list) -> list:
+    """Look up the land use type from management nodes."""
+    return [
+        {
+            "id": node.get("term", {}).get("@id"),
+            "land-use-type": _get_land_use_term_from_node(node),
+            "endDate": _gapfill_datestr(datestr=node.get("endDate"), mode=DatestrGapfillMode.END)[:10]
+        } for node in nodes
+    ]
+
+
+def _no_prior_land_cover_data(nodes: list, end_date: str) -> bool:
+    target_date = (
+        datetime.strptime(end_date, DatestrFormat.YEAR_MONTH_DAY.value)
+        - timedelta(days=DEFAULT_WINDOW_IN_YEARS * DAYS_IN_YEAR)
+    )
+    previous_nodes = [
+        node for node in nodes
+        if abs(_node_date(node) - target_date) < timedelta(days=DATE_TOLERANCE_IN_YEARS * DAYS_IN_YEAR)
+    ]
+    return len(previous_nodes) == 0
+
+
+def _should_run(site: dict, management_nodes: list) -> tuple[bool, dict]:
+    summarised_nodes = _collect_land_use_types(management_nodes)
+    allowed_land_use_types = [ANNUAL_CROPLAND, PERMANENT_CROPLAND, PERMANENT_PASTURE]
+    relevant_nodes = sorted(
+        [
+            node for node in summarised_nodes
+            if node["land-use-type"] in allowed_land_use_types
+        ],
+        key=lambda n: n.get("endDate")
+    )
+    land_use_type = relevant_nodes[0].get("land-use-type") if relevant_nodes else None
+
+    has_no_prior_land_cover_data = _no_prior_land_cover_data(
+        nodes=management_nodes,
+        end_date=relevant_nodes[-1:][0].get("endDate")
+    ) if relevant_nodes else None
+
+    should_run_nodes, site_area = _should_run_historical_land_use_change(
+        site=site,
+        nodes=management_nodes,
+        land_use_type=land_use_type
+    ) if all([land_use_type, has_no_prior_land_cover_data]) else (False, {})
+
+    logRequirements(site, model=MODEL, model_key=MODEL_KEY,
+                    has_management_nodes=bool(management_nodes),
+                    land_use_type=land_use_type,
+                    allowed_land_use_types=';'.join(allowed_land_use_types),
+                    has_no_prior_land_cover_data=has_no_prior_land_cover_data,
+                    summarised_nodes=log_as_table(summarised_nodes))
+
+    should_run = all([land_use_type, has_no_prior_land_cover_data, should_run_nodes])
+    logShouldRun(site, MODEL, None, should_run, model_key=MODEL_KEY)
+    return should_run_nodes, site_area
 
 
 def run(site: dict) -> list:
-    should_run, site_area = _should_run(site)
-    management_nodes = filter_list_term_type(site.get("management", []), TermTermType.LANDCOVER)
-    return _run_make_management_nodes(
-        existing_nodes=management_nodes,
-        percentage_transformed_from=site_area,
-        start_year=int(management_nodes[0].get("endDate")[:4]) - DEFAULT_WINDOW_IN_YEARS
-    ) if should_run else []
+    management_nodes = [
+        node for node in filter_list_term_type(site.get("management", []), TermTermType.LANDCOVER)
+        if not _should_group_landCover(node)
+    ]
+    should_run, site_area = _should_run(site=site, management_nodes=management_nodes)
+    return _run(site, management_nodes, site_area) if should_run else []
