@@ -25,7 +25,7 @@ MODEL_KEY = 'value'
 
 
 def _run(impact: dict, product: dict):
-    return {**impact.get('product'), MODEL_KEY: product.get(MODEL_KEY, [])}
+    return impact.get('product') | {MODEL_KEY: product.get(MODEL_KEY, [])}
 
 
 def _should_run(impact: dict):
