@@ -154,6 +154,7 @@ LAND_USE_CATEGORY_PARAMS = [
     ("set-aside", IpccSoilCategory.LOW_ACTIVITY_CLAY_SOILS, IpccLandUseCategory.SET_ASIDE),
     ("set-aside-override", IpccSoilCategory.LOW_ACTIVITY_CLAY_SOILS, IpccLandUseCategory.SET_ASIDE),
     ("upland-rice", IpccSoilCategory.LOW_ACTIVITY_CLAY_SOILS, IpccLandUseCategory.ANNUAL_CROPS),
+    ("unknown", IpccSoilCategory.LOW_ACTIVITY_CLAY_SOILS, IpccLandUseCategory.UNKNOWN)
 ]
 
 
@@ -194,14 +195,14 @@ MANAGEMENT_CATEGORY_PARAMS = [
     ("full-tillage", IpccLandUseCategory.ANNUAL_CROPS, IpccManagementCategory.FULL_TILLAGE),
     ("high-intensity-grazing", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.HIGH_INTENSITY_GRAZING),
     ("improved-grassland", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.IMPROVED_GRASSLAND),
-    ("no-management/annual-crops", IpccLandUseCategory.ANNUAL_CROPS, IpccManagementCategory.FULL_TILLAGE),
-    ("no-management/annual-crops-wet", IpccLandUseCategory.ANNUAL_CROPS_WET, IpccManagementCategory.FULL_TILLAGE),
-    ("no-management/grassland", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.NOMINALLY_MANAGED),
     ("no-tillage", IpccLandUseCategory.ANNUAL_CROPS, IpccManagementCategory.NO_TILLAGE),
     ("nominally-managed", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.NOMINALLY_MANAGED),
-    ("other", IpccLandUseCategory.OTHER, IpccManagementCategory.OTHER),
+    ("not-relevant", IpccLandUseCategory.OTHER, IpccManagementCategory.NOT_RELEVANT),
     ("reduced-tillage", IpccLandUseCategory.ANNUAL_CROPS, IpccManagementCategory.REDUCED_TILLAGE),
     ("severely-degraded", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.SEVERELY_DEGRADED),
+    ("unknown/annual-crops", IpccLandUseCategory.ANNUAL_CROPS, IpccManagementCategory.UNKNOWN),
+    ("unknown/annual-crops-wet", IpccLandUseCategory.ANNUAL_CROPS_WET, IpccManagementCategory.UNKNOWN),
+    ("unknown/grassland", IpccLandUseCategory.GRASSLAND, IpccManagementCategory.UNKNOWN)
 ]
 
 
@@ -310,7 +311,10 @@ CARBON_INPUT_CATEGORY_PARAMS = [
         "grassland-medium/1-improvements",
         IpccManagementCategory.IMPROVED_GRASSLAND,
         IpccCarbonInputCategory.GRASSLAND_MEDIUM
-    )
+    ),
+    ("not-relevant", IpccManagementCategory.NOT_RELEVANT, IpccCarbonInputCategory.NOT_RELEVANT),
+    ("unknown/cropland", IpccManagementCategory.FULL_TILLAGE, IpccCarbonInputCategory.UNKNOWN),
+    ("unknown/grassland", IpccManagementCategory.IMPROVED_GRASSLAND, IpccCarbonInputCategory.UNKNOWN)
 ]
 
 
@@ -395,18 +399,18 @@ def test_calc_soc_stocks(regime_start_years, soc_equilibriums, expected):
 TEST_INVENTORY = {
         1960: {
             _InventoryKey.LU_CATEGORY: IpccLandUseCategory.FOREST,
-            _InventoryKey.MG_CATEGORY: IpccManagementCategory.OTHER,
-            _InventoryKey.CI_CATEGORY: IpccCarbonInputCategory.OTHER
+            _InventoryKey.MG_CATEGORY: IpccManagementCategory.NOT_RELEVANT,
+            _InventoryKey.CI_CATEGORY: IpccCarbonInputCategory.NOT_RELEVANT
         },
         1965: {
             _InventoryKey.LU_CATEGORY: IpccLandUseCategory.FOREST,
-            _InventoryKey.MG_CATEGORY: IpccManagementCategory.OTHER,
-            _InventoryKey.CI_CATEGORY: IpccCarbonInputCategory.OTHER
+            _InventoryKey.MG_CATEGORY: IpccManagementCategory.NOT_RELEVANT,
+            _InventoryKey.CI_CATEGORY: IpccCarbonInputCategory.NOT_RELEVANT
         },
         1970: {
             _InventoryKey.LU_CATEGORY: IpccLandUseCategory.GRASSLAND,
             _InventoryKey.MG_CATEGORY: IpccManagementCategory.NOMINALLY_MANAGED,
-            _InventoryKey.CI_CATEGORY: IpccCarbonInputCategory.OTHER
+            _InventoryKey.CI_CATEGORY: IpccCarbonInputCategory.NOT_RELEVANT
         },
         1995: {
             _InventoryKey.LU_CATEGORY: IpccLandUseCategory.ANNUAL_CROPS,
@@ -434,7 +438,7 @@ EXPECTED_MISSING_YEARS = {
     1990: {
         _InventoryKey.LU_CATEGORY: IpccLandUseCategory.GRASSLAND,
         _InventoryKey.MG_CATEGORY: IpccManagementCategory.NOMINALLY_MANAGED,
-        _InventoryKey.CI_CATEGORY: IpccCarbonInputCategory.OTHER
+        _InventoryKey.CI_CATEGORY: IpccCarbonInputCategory.NOT_RELEVANT
     },
     2023: {
         _InventoryKey.LU_CATEGORY: IpccLandUseCategory.ANNUAL_CROPS,
